@@ -31,24 +31,16 @@ TransactionListener::TransactionListener(QObject *parent)
     , m_transaction(nullptr)
 {
     connect(TransactionModel::global(), &TransactionModel::transactionAdded, this, &TransactionListener::transactionAdded);
-    connect(TransactionModel::global(), &TransactionModel::transactionRemoved, this, &TransactionListener::transactionRemoved);
-    connect(TransactionModel::global(), &TransactionModel::transactionCancelled, this, &TransactionListener::transactionCancelled);
 }
 
 void TransactionListener::cancel()
 {
     if(!isCancellable()) {
-        qWarning() << "cannot cancel the transaction" << m_transaction;
         return;
     }
     m_transaction->cancel();
 }
 
-AbstractResource *TransactionListener::resource() const
-{
-    return m_resource;
-}
-
 bool TransactionListener::isCancellable() const
 {
     return m_transaction && m_transaction->isCancellable();
@@ -67,15 +59,18 @@ QString TransactionListener::statusText() const
 }
 
 void TransactionListener::setResource(AbstractResource *resource)
+{
+    setResourceInternal(resource);
+    // Catch already-started transactions
+    setTransaction(TransactionModel::global()->transactionFromResource(resource));
+}
+
+void TransactionListener::setResourceInternal(AbstractResource* resource)
 {
     if (m_resource == resource)
         return;
 
     m_resource = resource;
-
-    // Catch already-started transactions
-    setTransaction(TransactionModel::global()->transactionFromResource(resource));
-
     emit resourceChanged();
 }
 
@@ -114,7 +109,6 @@ private:
 
 void TransactionListener::setTransaction(Transaction* trans)
 {
-    Q_ASSERT(!trans || trans->resource()==m_resource);
     if (m_transaction == trans) {
         return;
     }
@@ -133,12 +127,22 @@ void TransactionListener::setTransaction(Transaction* trans)
         connect(m_transaction, &Transaction::cancellableChanged, this, &TransactionListener::cancellableChanged);
         connect(m_transaction, &Transaction::statusChanged, this, &TransactionListener::transactionStatusChanged);
         connect(m_transaction, &Transaction::progressChanged, this, &TransactionListener::progressChanged);
+        connect(m_transaction, &QObject::destroyed, this, [this]() {
+            qDebug() << "destroyed transaction before finishing";
+            setTransaction(nullptr);
+        });
+        setResourceInternal(trans->resource());
     }
+    Q_EMIT transactionChanged(trans);
 }
 
 void TransactionListener::transactionStatusChanged(Transaction::Status status)
 {
     switch (status) {
+    case Transaction::CancelledStatus:
+        setTransaction(nullptr);
+        emit cancelled();
+        break;
     case Transaction::DoneStatus:
         setTransaction(nullptr);
         break;
@@ -149,21 +153,6 @@ void TransactionListener::transactionStatusChanged(Transaction::Status status)
     emit statusTextChanged();
 }
 
-void TransactionListener::transactionRemoved(Transaction* trans)
-{
-    if(m_transaction == trans) {
-        setTransaction(nullptr);
-    }
-}
-
-void TransactionListener::transactionCancelled(Transaction* trans)
-{
-    if(m_transaction == trans) {
-        setTransaction(nullptr);
-    }
-    emit cancelled();
-}
-
 int TransactionListener::progress() const
 {
     return m_transaction ? m_transaction->progress() : 0;
