@@ -24,6 +24,8 @@
 #include <KShell>
 #include <QProcess>
 #include <QRegularExpression>
+
+#include "ReviewsBackend/Rating.h"
 #include <knewstuff_version.h>
 
 KNSResource::KNSResource(const KNSCore::EntryInternal& entry, QStringList categories, KNSBackend* parent)
@@ -223,3 +225,18 @@ void KNSResource::invokeApplication() const
         qWarning() << "cannot execute" << packageName();
     }
 }
+
+Rating * KNSResource::ratingInstance()
+{
+    if (!m_rating) {
+        const int noc = m_entry.numberOfComments();
+        const int rating = m_entry.rating();
+        Q_ASSERT(rating <= 100);
+        return new Rating(
+            packageName(),
+            noc,
+            { { QStringLiteral("star5"), rating } }
+        );
+    }
+    return m_rating;
+}
