@@ -23,6 +23,7 @@
 
 #include <resources/AbstractResource.h>
 #include <KNSCore/EntryInternal>
+#include <QPointer>
 #include <attica/content.h>
 
 #include "discovercommon_export.h"
@@ -38,7 +39,7 @@ public:
     AbstractResource::State state() const override;
     QVariant icon() const override;
     QString comment() override;
-    QString name() override;
+    QString name() const override;
     QString packageName() const override;
     QStringList categories() override;
     QUrl homepage() override;
@@ -65,10 +66,13 @@ public:
 
     QUrl url() const override;
 
+    Rating* ratingInstance();
+
 private:
     const QStringList m_categories;
     KNSCore::EntryInternal m_entry;
     KNS3::Entry::Status m_lastStatus;
+    QPointer<Rating> m_rating;
 };
 
 #endif // KNSRESOURCE_H
