@@ -46,9 +46,14 @@ QString AppPackageKitResource::name() const
     QString ret;
     if (!m_appdata.extends().isEmpty()) {
         auto components = backend()->componentsById(m_appdata.extends().constFirst());
-        Q_ASSERT(!components.isEmpty());
-        ret = components.constFirst().name() + QStringLiteral(" - ") + m_appdata.name();
-    } else
+
+        if (components.isEmpty())
+            qWarning() << "couldn't find" << m_appdata.extends() << "which is supposedly extended by" << m_appdata.id();
+        else
+            ret = components.constFirst().name() + QStringLiteral(" - ") + m_appdata.name();
+    }
+
+    if (ret.isEmpty())
         ret = m_appdata.name();
     return ret;
 }
@@ -195,11 +200,22 @@ void AppPackageKitResource::invokeApplication() const
         } else {
             const QStringList exes = m_appdata.provided(AppStream::Provided::KindBinary).items();
             const auto packageExecutables = kFilter<QStringList>(allServices, [filenames](const QString &exe) { return filenames.contains(QLatin1Char('/') + exe); });
-            if (packageExecutables.isEmpty()) {
-                qWarning() << "Could not find any executables" << exes << filenames;
-                return;
+            if (!packageExecutables.isEmpty()) {
+                QProcess::startDetached(exes.constFirst());
+            } else {
+                const auto locations = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
+                const auto desktopFiles = kFilter<QStringList>(filenames, [locations](const QString &exe) {
+                    for (const auto &location: locations) {
+                        if (exe.startsWith(location))
+                            return exe.contains(QLatin1String(".desktop"));
+                    }
+                    return false;
+                });
+                if (!desktopFiles.isEmpty()) {
+                    QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), { desktopFiles });
+                }
             }
-            QProcess::startDetached(exes.constFirst());
+            qWarning() << "Could not find any executables" << exes << filenames;
         }
     });
 }
