@@ -48,10 +48,13 @@ class DISCOVERCOMMON_EXPORT StandardBackendUpdater : public AbstractBackendUpdat
         bool isCancelable() const override;
         bool isProgressing() const override;
         bool isMarked(AbstractResource* res) const override;
+        double updateSize() const override;
         void setProgress(qreal p);
         int updatesCount() const;
+        void cancel() override;
 
     Q_SIGNALS:
+        void cancelTransaction();
         void updatesCountChanged(int updatesCount);
 
     public Q_SLOTS:
@@ -72,6 +75,7 @@ class DISCOVERCOMMON_EXPORT StandardBackendUpdater : public AbstractBackendUpdat
         qreal m_progress;
         QDateTime m_lastUpdate;
         QTimer m_timer;
+        bool m_canCancel = false;
 };
 
 #endif // STANDARDBACKENDUPDATER_H
